@@ -1,11 +1,4 @@
 package MouseX::AttributeHelpers::Bool;
-
-{
-    package # hide from PAUSE
-        Mouse::Meta::Attribute::Custom::Bool;
-    sub register_implementation { 'MouseX::AttributeHelpers::Bool' }
-}
-
 use Mouse;
 
 extends 'MouseX::AttributeHelpers::Base';
@@ -36,8 +29,8 @@ has '+method_constructors' => (
 sub helper_type { 'Bool' }
 
 no Mouse;
-
-1;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
+__END__
 
 =head1 NAME
 
