@@ -1,11 +1,4 @@
 package MouseX::AttributeHelpers::Number;
-
-{
-    package # hide from PAUSE
-        Mouse::Meta::Attribute::Custom::Number;
-    sub register_implementation { 'MouseX::AttributeHelpers::Number' }
-}
-
 use Mouse;
 
 extends 'MouseX::AttributeHelpers::Base';
@@ -48,8 +41,8 @@ has '+method_constructors' => (
 sub helper_type { 'Num' }
 
 no Mouse;
-
-1;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
+__END__
 
 =head1 NAME
 
